summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2019-12-01 13:28:14 +0100
committerRay <[email protected]>2019-12-01 13:28:14 +0100
commit3ffe34f9bb6452c021dfff0c2b04411542920c22 (patch)
tree7709985f319fa7d1c2d9a836b8536954a42c6436 /src/raylib.h
parent416a52b5bc6b1c0ec0d3acf4b86521a96f017811 (diff)
downloadraylib-3ffe34f9bb6452c021dfff0c2b04411542920c22.tar.gz
raylib-3ffe34f9bb6452c021dfff0c2b04411542920c22.zip
ADDED: DrawTextCodepoint()
- Renamed GetGlyphIndex() parameter - Review DrawTextEx() implementation - Review DrawTextRecEx() implementation
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/raylib.h b/src/raylib.h
index d7087e87..1dfcdc64 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -1185,12 +1185,13 @@ RLAPI void DrawText(const char *text, int posX, int posY, int fontSize, Color co
RLAPI void DrawTextEx(Font font, const char *text, Vector2 position, float fontSize, float spacing, Color tint); // Draw text using font and additional parameters
RLAPI void DrawTextRec(Font font, const char *text, Rectangle rec, float fontSize, float spacing, bool wordWrap, Color tint); // Draw text using font inside rectangle limits
RLAPI void DrawTextRecEx(Font font, const char *text, Rectangle rec, float fontSize, float spacing, bool wordWrap, Color tint,
- int selectStart, int selectLength, Color selectText, Color selectBack); // Draw text using font inside rectangle limits with support for text selection
+ int selectStart, int selectLength, Color selectTint, Color selectBackTint); // Draw text using font inside rectangle limits with support for text selection
+RLAPI void DrawTextCodepoint(Font font, int codepoint, Vector2 position, float scale, Color tint); // Draw one character (codepoint)
// Text misc. functions
RLAPI int MeasureText(const char *text, int fontSize); // Measure string width for default font
RLAPI Vector2 MeasureTextEx(Font font, const char *text, float fontSize, float spacing); // Measure string size for Font
-RLAPI int GetGlyphIndex(Font font, int character); // Get index position for a unicode character on font
+RLAPI int GetGlyphIndex(Font font, int codepoint); // Get index position for a unicode character on font
// Text strings management functions (no utf8 strings, only byte chars)
// NOTE: Some strings allocate memory internally for returned strings, just be careful!